# KText

## 1.功能介绍
    用于基础的机器学习&文本分析
    完成基本的分类和回归任务
    对文本进行简单的分析与挖掘

## 2.依赖
    python3.8
    numpy
    pandas
    matplotlib
    seaborn
    skearn
    xgboost
    gensim
    imblearn
    jieba

## 项目结构
    .
    │  README.md
    │
    └─KText
        │  analyze.py
        │  chineseStopWords.txt
        │  FE.py
        │  preProcess.py
        └─  __init__.py

## Others
    @Author: Kevin